import { ConfigModule } from '@nestjs/config';
import { CouchDataController } from './infrastructure/couch.controller';
import { Module } from '@nestjs/common';
import { CouchService } from './data/services/couch.service';
import { CqrsModule } from '@nestjs/cqrs';
import {
  PaymentMethodUpdatedHandler,
  PaymentMethodDeletedHandler,
} from './domain/managers/payment-method.handler';
import {
  VipCategoryDeletedHandler,
  VipCategoryUpdatedHandler,
} from './domain/managers/vip-category.handler';
import {
  SeasonPeriodDeletedHandler,
  SeasonPeriodUpdatedHandler,
} from './domain/managers/season-period.handler';

@Module({
  imports: [ConfigModule.forRoot(), CqrsModule],
  controllers: [CouchDataController],
  providers: [
    PaymentMethodDeletedHandler,
    PaymentMethodUpdatedHandler,
    VipCategoryDeletedHandler,
    VipCategoryUpdatedHandler,
    SeasonPeriodDeletedHandler,
    SeasonPeriodUpdatedHandler,

    CouchService,
  ],
})
export class CouchModule {}
